# back compatibility package for any code explicitly checking
# that the filehandle object is a Fh
package Fh;

use strict;
use warnings;

1;
